@@ -1,8 +1,8 @@
 from .alexnet_ecoset import Alexnet_ecoset
-from .barlowtwins import BarlowTwins
+from .alexnet_salobjsub import AlexNet_SalObjSub
 from .resnet50_ecoset import Resnet50_ecoset
-from .swav import Swav
 from .vgg16_ecoset import VGG16_ecoset
 from .openclip import OpenCLIP
 from .inception_ecoset import Inception_ecoset
 from .official_clip import clip
+# from .harmonization import Harmonization
